@@ -43,7 +43,11 @@ public:
     void setLayer(uint32_t layer);
 
     void applyConfigure() override;
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     void setWindowGeometry(const QRect &geometry) override;
+#else
+    void setWindowSize(const QSize &size) override;
+#endif
 
     bool requestActivate() override;
     void setXdgActivationToken(const QString &token) override;
@@ -61,7 +65,9 @@ private:
     QString m_activationToken;
 
     bool m_configured = false;
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     bool m_configuring = false;
+#endif
 };
 
 }
